.. _libraries_and_templates:

Libraries and templates
=======================

Water Resources Management Library (Example)
--------------------------------------------

HydropowerReservoir
~~~~~~~~~~~~~~~~~~~

- Dam Height
- Dam Type
- Max Storage
- Min Storage
- Maximum Turbine Release
- Maximum Spillgate Release
- Maximum Bottom Outlet Release
- Storage Area Elevation
- Seepage
- Turbine Elevation
- Turbine HeadLoss
- Tailwater Elevation
- Turbine Efficiency
- Evaporation
- Inflow
- Sediment Load
- Energy Price

WWTP
~~~~

- Organic Carbon Load
- Suspended Solids Load
- Max Capacity
- Energy Cost
- Aeration Capacity

Irrigation
~~~~~~~~~~

- Crop
- Irrigation Type
- Potential Evapotranspiration
- Vegetation Cycle
- Soil Moisture
- Return Flow
